package com.ruoyi.ss.model.service;

import com.ruoyi.ss.model.domain.ModelBO;
import com.ruoyi.ss.model.domain.ModelQuery;
import com.ruoyi.ss.model.domain.ModelVO;

import java.util.List;

/**
 * 型号列表Service接口
 *
 * @author 邱贞招
 * @date 2024-02-21
 */
public interface IModelService
{
    /**
     * 查询型号列表
     *
     * @param modelId 型号列表主键
     * @return 型号列表
     */
    public ModelVO selectSmModelByModelId(Long modelId);

    /**
     * 查询型号列表列表
     *
     * @param smModel 型号列表
     * @return 型号列表集合
     */
    public List<ModelVO> selectSmModelList(ModelQuery smModel);

    /**
     * 新增型号列表
     *
     * @param smModel 型号列表
     * @return 结果
     */
    public int insertSmModel(ModelBO smModel);

    /**
     * 修改型号列表
     *
     * @param smModel 型号列表
     * @return 结果
     */
    public int updateSmModel(ModelBO smModel);

    /**
     * 批量删除型号列表
     *
     * @param modelIds 需要删除的型号列表主键集合
     * @return 结果
     */
    public int deleteSmModelByModelIds(Long[] modelIds);

    /**
     * 删除型号列表信息
     *
     * @param modelId 型号列表主键
     * @return 结果
     */
    public int deleteSmModelByModelId(Long modelId);

    /**
     * 条件查询数量
     * @param dto 查询条件
     * @return 结果
     */
    Integer selectCount(ModelQuery dto);

    /**
     * 逻辑删除
     */
    int logicDelete(List<Long> modelIds);

    /**
     * 根据型号查询数据
     */
    ModelVO selectByModel(String model);

//    /**
//     * 创建初始型号
//     */
//    int addInitModel(IotDeviceInfo deviceInfo);

    ModelVO selectOne(ModelQuery query);
}
